# 🌐 Jasper

![image](https://kamangir-public.s3.ca-central-1.amazonaws.com/geo-watch-2024-09-06-Jasper-a/geo-watch-2024-09-06-Jasper-a-2X.gif?raw=true&random=mJahtfyzlU0VkVYT)

--table--

The fire originates in the bottom right, crosses the river, and causes the colors to shift from green to brown.

- [Wikipedia: 2024 Jasper wildfire](https://en.wikipedia.org/wiki/2024_Jasper_wildfire)
- [Google Map](https://maps.app.goo.gl/o5tGW4tH5S6j4vso9): `lat: 52.8733° N`, `lon: 118.0823° W`.
- [Wildfire status — Jasper Wildfire Complex](https://parks.canada.ca/pn-np/ab/jasper/visit/feu-alert-fire/feudeforet-wildfire).

details: [targets.yaml](../targets.yaml).

used by: [`@geo watch`](../).